from h5py import File, Group
from thd_json import header
from h5schemas.scan_schema import open_schema
from h5schemas.initialize_dataset import initialize_dataset
from datetime import datetime


def init_header(
    h5_file: File | Group,
):
    schema_groups = get_header_schemas()
    initialize_dataset(h5_file, schema_groups)


def get_header_schemas():
    return open_schema(header, "header.json")


def check_uuid_time_stamp(uuid: str | None = None, timestamp: int | None = None):
    if uuid is None:
        json_header = header.generate_header()
        uuid = json_header.uuid

    if timestamp is None:
        timestamp = datetime.fromisoformat(json_header.timestamp).timestamp()

    return uuid, timestamp


def add_header_sample(
    h5_file: File | Group, uuid: str | None, timestamp: float | None = None
):
    uuid, timestamp = check_uuid_time_stamp(uuid, timestamp)

    dst = h5_file["uuid"]
    dst.resize((dst.shape[0] + 1,))
    dst[-1,] = uuid

    dst = h5_file["timestamp"]
    dst.resize((dst.shape[0] + 1,))
    dst[-1,] = timestamp


def uuid_time_from_json_header(json_header_obj: header.JsonHeader) -> tuple[str, float]:
    return json_header_obj.uuid, datetime.fromisoformat(
        json_header_obj.timestamp
    ).timestamp()


if __name__ == "__main__":
    from h5schemas.header.overwrite_header import overwrite_header_at_index
    test_file = File("./examples/header.h5", "a")
    init_header(test_file)

    add_header_sample(test_file, None)
    add_header_sample(test_file, None)
    add_header_sample(test_file, None)
    add_header_sample(test_file, *uuid_time_from_json_header(header.generate_header()))
    overwrite_header_at_index(test_file, 0, 'test', 0.0)