from h5py import File, Group
from pathlib import Path
import numpy as np

from h5schemas.header.add_header import check_uuid_time_stamp
from h5schemas.image.overwrite_image import overwrite_image_at_index
from h5schemas.projection_geometry.overwrite_projection_geometry import overwrite_projection_geometry_at_index
from h5schemas.source.overwrite_source import overwrite_source_at_index


def overwrite_projection_at_index(
    h5_file: File,
    index: int,
    image: Path | np.ndarray,
    detector_center_position_mm: tuple[float, float, float],
    detector_center_orientation_quat: tuple[float, float, float, float],
    focal_spot_position_mm: tuple[float, float, float],
    focal_spot_orientation_quat: tuple[float, float, float, float] | None = None,
    current_ma: float = 0,
    voltage_kv: float = 0,
    uuid: str | None = None,
    timestamp: int | None = None,
):
    uuid, timestamp = check_uuid_time_stamp(uuid, timestamp)
    overwrite_image_at_index(h5_file["/image"], index, image, uuid, timestamp)


    overwrite_projection_geometry_at_index(
        h5_file["/projection_geometry"],
        index,
        detector_center_position_mm,
        detector_center_orientation_quat,
        focal_spot_position_mm,
        focal_spot_orientation_quat,
        uuid,
        timestamp,
    )
    overwrite_projection_geometry_at_index(
        h5_file["/projection_geometry_nominal"],
        index,
        detector_center_position_mm,
        detector_center_orientation_quat,
        focal_spot_position_mm,
        focal_spot_orientation_quat,
        uuid,
        timestamp,
    )

    overwrite_source_at_index(h5_file["/source"], index, current_ma, voltage_kv)
