from h5py import File, Group
import numpy as np
from h5schemas.header.overwrite_header import overwrite_header_at_index




def overwrite_projection_geometry_at_index(
    h5_file: File | Group,
    index: int,
    detector_center_position_mm: tuple[float, float, float],
    detector_center_orientation_quat: tuple[float, float, float, float],
    focal_spot_position_mm: tuple[float, float, float],
    focal_spot_orientation_quat: tuple[float, float, float, float] | None = None,
    uuid: str | None = None,
    timestamp: float | None = None,
):
    update_values = list()

    def insert_update(values):
        dst, value = values
        dst[index] = value

    update_values.append(
        [h5_file["detector_center_position_mm/x"], detector_center_position_mm[0]]
    )
    update_values.append(
        [h5_file["detector_center_position_mm/y"], detector_center_position_mm[1]]
    )
    update_values.append(
        [h5_file["detector_center_position_mm/z"], detector_center_position_mm[2]]
    )

    update_values.append(
        [
            h5_file["detector_center_orientation_quat/x"],
            detector_center_orientation_quat[0],
        ]
    )
    update_values.append(
        [
            h5_file["detector_center_orientation_quat/y"],
            detector_center_orientation_quat[1],
        ]
    )
    update_values.append(
        [
            h5_file["detector_center_orientation_quat/z"],
            detector_center_orientation_quat[2],
        ]
    )
    update_values.append(
        [
            h5_file["detector_center_orientation_quat/w"],
            detector_center_orientation_quat[3],
        ]
    )

    update_values.append(
        [h5_file["focal_spot_position_mm/x"], focal_spot_position_mm[0]]
    )
    update_values.append(
        [h5_file["focal_spot_position_mm/y"], focal_spot_position_mm[1]]
    )
    update_values.append(
        [h5_file["focal_spot_position_mm/z"], focal_spot_position_mm[2]]
    )

    if focal_spot_orientation_quat is None:
        focal_spot_orientation_quat = (0.0, 0.0, 0.0, 1.0)

    update_values.append(
        [h5_file["focal_spot_orientation_quat/x"], focal_spot_orientation_quat[0]]
    )
    update_values.append(
        [h5_file["focal_spot_orientation_quat/y"], focal_spot_orientation_quat[1]]
    )
    update_values.append(
        [h5_file["focal_spot_orientation_quat/z"], focal_spot_orientation_quat[2]]
    )
    update_values.append(
        [h5_file["focal_spot_orientation_quat/w"], focal_spot_orientation_quat[3]]
    )

    for value in update_values:
        insert_update(value)
    
    overwrite_header_at_index(h5_file['header'], index, uuid, timestamp)